==> anki-0.9.9.5_1.tbz: lib/python2.5/site-packages/ankiqt-0.9.9.5-py2.5.egg/ankiqt/config.py <==
# Copyright: Damien Elmes <anki@ichi2.net>
# License: GNU GPL, version 3 or later; http://www.gnu.org/copyleft/gpl.html

# User configuration handling
##########################################################################

from PyQt4.QtGui import *
from PyQt4.QtCore import *
import os, sys, cPickle, locale, types, shutil, time
from anki.utils import genID

# compatability
def unpickleWxFont(*args):
    pass
def pickleWxFont(*args):
    pass

class Config(dict):

    configDbName = "config.db"

    def __init__(self, configPath):
        self.configPath = configPath
        if sys.platform == "win32":
            if self.configPath.startswith("~"):
                # windows sucks
                self.configPath = "c:\\anki"
        elif sys.platform.startswith("darwin"):
            if self.configPath == os.path.expanduser("~/.anki"):
                oldDb = self.getDbPath()
                self.configPath = os.path.expanduser(
                    "~/Library/Application Support/Anki")
                # upgrade?
                if (not os.path.exists(self.configPath) and
                    os.path.exists(oldDb)):
                    self.makeAnkiDir()
                    newDb = self.getDbPath()
                    shutil.copy2(oldDb, newDb)
        self.makeAnkiDir()
        self.load()

    def defaults(self):
        fields = {
            'iconSize': 32,
            'syncOnLoad': False,
            'syncOnClose': False,
            'checkForUpdates': True,
            'interfaceLang': "",
            'syncUsername': "",
            'syncPassword': "",
            'showFontPreview': False,
            'showToolbar': True,
            'recentDeckPaths': [],
            'saveAfterAnswer': True,
            'saveAfterAnswerNum': 10,
            'saveAfterAdding': True,
            'saveAfterAddingNum': 3,
            'saveOnClose': True,
            'mainWindowGeom': None,
            'easeButtonHeight': 'standard',
            'suppressUpdate': False,
            'suppressEstimates': False,
            'showLastCardInterval': False,
            'showLastCardContent': False,
            'showTrayIcon': False,
            'showTimer': True,
            'showSuspendedCards': True,
            'simpleToolbar': True,
            'scrollToAnswer': True,
            'qaDivider': True,
            'splitQA': True,
            'sortIndex': 0,
            'addZeroSpace': False,
            'alternativeTheme': False,
            'showStudyScreen': True,
            'showStudyOptions': False,
            'created': time.time(),
            'id': genID(),
            }
        for (k,v) in fields.items():
            if not self.has_key(k):
                self[k] = v
        if not self['interfaceLang']:
            # guess interface and target languages
            (lang, enc) = locale.getdefaultlocale()
            self['interfaceLang'] = lang
        self.initFonts()

    def initFonts(self):
        defaultColours = {
                'lastCard': "#0077FF",
                'background': "#FFFFFF",
                'interface': "#000000",
            }
        defaultSizes = {
                'interface': 12,
                'lastCard': 14,
                'edit': 12,
                'other': 24,
            }
        # fonts
        for n in ("interface", "lastCard", "edit"):
            if not self.get(n + "FontFamily", None):
                self[n + "FontFamily"] = "Arial"
                self[n + "FontSize"] = defaultSizes.get(n, defaultSizes['other'])
        # colours
        for n in ("interface", "lastCard", "background"):
            color = n + "Colour"
            if not color in self:
                self[color] = defaultColours[n]

    def getDbPath(self):
        return os.path.join(self.configPath, self.configDbName)

    def makeAnkiDir(self):
        base = self.configPath
        for x in (base,
                  os.path.join(base, "plugins"),
                  os.path.join(base, "backups")):
            try:
                os.mkdir(x)
            except:
                pass

    def save(self):
        path = self.getDbPath()
        # write to a temp file
        from tempfile import mkstemp
        (fd, tmpname) = mkstemp(dir=os.path.dirname(path))
        tmpfile = os.fdopen(fd, 'w')
        cPickle.dump(dict(self), tmpfile)
        tmpfile.close()
        # the write was successful, delete config file (if exists) and rename
        if os.path.exists(path):
            os.unlink(path)
        os.rename(tmpname, path)

    def load(self):
        base = self.configPath
        db = self.getDbPath()
        # load config
        try:
            f = open(db)
            self.update(cPickle.load(f))
        except (IOError, EOFError):
            # config file was corrupted previously
            pass
        self.defaults()
        # fix old recent deck path list
        for n in range(len(self['recentDeckPaths'])):
            s = self['recentDeckPaths'][n]
            if not isinstance(s, types.UnicodeType):
                self['recentDeckPaths'][n] = unicode(s, sys.getfilesystemencoding())
        # fix old locale settings
        if self["interfaceLang"] == "ja":
            self["interfaceLang"]="ja_JP"
        elif self["interfaceLang"] == "fr":
            self["interfaceLang"]="fr_FR"
        elif self["interfaceLang"] == "en":
            self["interfaceLang"]="en_US"
        elif self["interfaceLang"] == "de":
            self["interfaceLang"]="de_DE"
        elif self["interfaceLang"] == "es":
            self["interfaceLang"]="es_ES"
        elif not self["interfaceLang"]:
            self["interfaceLang"]="en_US"

==> anki-1.0.1.tbz: lib/python2.6/site-packages/ankiqt-1.0.1-py2.6.egg/ankiqt/config.py <==
# Copyright: Damien Elmes <anki@ichi2.net>
# License: GNU GPL, version 3 or later; http://www.gnu.org/copyleft/gpl.html

# User configuration handling
##########################################################################

from PyQt4.QtGui import *
from PyQt4.QtCore import *
import os, sys, cPickle, locale, types, shutil, time, re
from anki.utils import genID

# compatability
def unpickleWxFont(*args):
    pass
def pickleWxFont(*args):
    pass

class Config(dict):

    configDbName = "config.db"

    def __init__(self, configPath):
        self.configPath = configPath
        if sys.platform == "win32":
            if self.configPath.startswith("~"):
                # windows sucks
                self.configPath = "c:\\anki"
        elif sys.platform.startswith("darwin"):
            if self.configPath == os.path.expanduser("~/.anki"):
                oldDb = self.getDbPath()
                self.configPath = os.path.expanduser(
                    "~/Library/Application Support/Anki")
                # upgrade?
                if (not os.path.exists(self.configPath) and
                    os.path.exists(oldDb)):
                    self.makeAnkiDir()
                    newDb = self.getDbPath()
                    shutil.copy2(oldDb, newDb)
        self.makeAnkiDir()
        self.load()

    def defaults(self):
        fields = {
            'addZeroSpace': False,
            'alternativeTheme': False,
            'checkForUpdates': True,
            'colourTimes': True,
            'created': time.time(),
            'deckBrowserNameLength': 30,
            'deckBrowserOrder': 0,
            'deckBrowserRefreshPeriod': 3600,
            'deleteMedia': False,
            'documentDir': u"",
            'editFontFamily': 'Arial',
            'editFontSize': 12,
            'editLineSize': 20,
            'editorReverseOrder': False,
            'extraNewCards': 5,
            'factEditorAdvanced': False,
            'forceLTR': False,
            'iconSize': 32,
            'id': genID(),
            'interfaceLang': "",
            'loadLastDeck': False,
            'mainWindowGeom': None,
            'mainWindowState': None,
            'numBackups': 30,
            'preventEditUntilAnswer': False,
            'proxyHost': '',
            'proxyPass': '',
            'proxyPort': 8080,
            'proxyUser': '',
            'qaDivider': True,
            'randomizeOnCram': True,
            'recentColours': ["#000000", "#0000ff"],
            'recentDeckPaths': [],
            'repeatQuestionAudio': True,
            'saveAfterAdding': True,
            'saveAfterAddingNum': 1,
            'saveAfterAnswer': True,
            'saveAfterAnswerNum': 10,
            'saveOnClose': True,
            'scrollToAnswer': True,
            'showCardTimer': True,
            'showFontPreview': False,
            'showLastCardContent': False,
            'showLastCardInterval': False,
            'showProgress': True,
            'showStudyOptions': False,
            'showStudyScreen': True,
            'showStudyStats': True,
            'showTimer': True,
            'showToolbar': True,
            'showTrayIcon': False,
            'simpleToolbar': True,
            'sortIndex': 0,
            'splitQA': True,
            'standaloneWindows': True,
            'suppressEstimates': False,
            'suppressUpdate': False,
            'syncInMsgBox': False,
            'syncOnClose': False,
            'syncOnLoad': False,
            'syncOnProgramClose': True,
            'syncOnProgramOpen': True,
            'syncPassword': "",
            'syncUsername': "",
            'typeAnswerFontSize': 20,
            }
        # disable sync on deck load when upgrading
        if not self.has_key("syncOnProgramOpen"):
            self['syncOnLoad'] = False
            self['syncOnClose'] = False
        for (k,v) in fields.items():
            if not self.has_key(k):
                self[k] = v
        if not self['interfaceLang']:
            # guess interface and target languages
            (lang, enc) = locale.getdefaultlocale()
            self['interfaceLang'] = lang

    def getDbPath(self):
        return os.path.join(self.configPath, self.configDbName)

    def makeAnkiDir(self):
        base = self.configPath
        for x in (base,
                  os.path.join(base, "plugins"),
                  os.path.join(base, "backups")):
            try:
                os.mkdir(x)
            except:
                pass

    def save(self):
        path = self.getDbPath()
        # write to a temp file
        from tempfile import mkstemp
        (fd, tmpname) = mkstemp(dir=os.path.dirname(path))
        tmpfile = os.fdopen(fd, 'w')
        cPickle.dump(dict(self), tmpfile)
        tmpfile.close()
        # the write was successful, delete config file (if exists) and rename
        if os.path.exists(path):
            os.unlink(path)
        os.rename(tmpname, path)

    def fixLang(self, lang):
        if lang and lang not in ("pt_BR", "zh_CN", "zh_TW"):
            lang = re.sub("(.*)_.*", "\\1", lang)
        if not lang:
            lang = "en"
        return lang

    def load(self):
        base = self.configPath
        db = self.getDbPath()
        # load config
        try:
            f = open(db)
            self.update(cPickle.load(f))
        except:
            # config file was corrupted previously
            pass
        self.defaults()
        # fix old recent deck path list
        for n in range(len(self['recentDeckPaths'])):
            s = self['recentDeckPaths'][n]
            if not isinstance(s, types.UnicodeType):
                self['recentDeckPaths'][n] = unicode(s, sys.getfilesystemencoding())
        # fix locale settings
        self["interfaceLang"] = self.fixLang(self["interfaceLang"])
